@@ -24,6 +24,11 @@ namespace Tomboy
 			//Ticks is in 100s of nanoseconds, unix time is in seconds
 			return (d.ToUniversalTime ().Ticks - epoch_ticks) / 10000000;
 		}
+
+		public string Version ()
+		{
+			return Defines.VERSION;
+		}
 	
 		public bool DisplayNote (string uri)
 		{
@@ -59,7 +64,13 @@ namespace Tomboy
 		public string FindNote (string linked_title)
 		{
 			Note note = note_manager.Find (linked_title);
-			return (note == null) ? "" : note.Uri;
+			return (note == null) ? String.Empty : note.Uri;
+		}
+		
+		public string FindStartHereNote ()
+		{
+			Note note = note_manager.FindByUri (NoteManager.StartNoteUri);
+			return (note == null) ? String.Empty : note.Uri;
 		}
 
 		public string CreateNote ()
