@@ -118,23 +118,26 @@ namespace Tomboy
 		}
 	}
 
+	public enum PanelOrientation { Horizontal, Vertical };
+	
 	public class TomboyTray : Gtk.EventBox
 	{
 		NoteManager manager;
 		Gtk.Tooltips tips;
 		Gtk.Image image;
-		PreferencesDialog prefs_dlg;
 		Gtk.Menu recent_menu;
 		bool menu_added = false;
 		List<Gtk.MenuItem> recent_notes = new List<Gtk.MenuItem> ();
+		int panel_size;
 
 		public TomboyTray (NoteManager manager) 
 			: base ()
 		{
 			this.manager = manager;
-			// Load a 24x24-sized icon to ensure we don't end up with a
+			// Load a 16x16-sized icon to ensure we don't end up with a
 			// 1x1 pixel.
-			this.image = new Gtk.Image (GuiUtils.GetIcon ("tomboy", 24));
+			panel_size = 16;
+			this.image = new Gtk.Image (GuiUtils.GetIcon ("tomboy", panel_size));
 
 			this.CanFocus = true;
 			this.ButtonPressEvent += ButtonPress;
@@ -155,7 +158,7 @@ namespace Tomboy
 			tips.SetTip (this, tip_text, null);
 			tips.Enable ();
 			tips.Sink ();
-
+			
 			SetupDragAndDrop ();
 			
 			recent_menu = MakeRecentNotesMenu ();
@@ -379,21 +382,6 @@ namespace Tomboy
 			GuiUtils.PopupMenu (recent_menu, null);
 		}
 
-		void OnPreferencesResponse (object sender, Gtk.ResponseArgs args)
-		{
-			((Gtk.Widget) sender).Destroy ();
-			prefs_dlg = null;
-		}
-
-		public void ShowPreferences ()
-		{
-			if (prefs_dlg == null) {
-				prefs_dlg = new PreferencesDialog (manager.PluginManager);
-				prefs_dlg.Response += OnPreferencesResponse;
-			}
-			prefs_dlg.Present ();
-		}
-
 		// Support dropping text/uri-lists and _NETSCAPE_URLs currently.
 		void SetupDragAndDrop ()
 		{
@@ -448,30 +436,72 @@ namespace Tomboy
 							insert_text.ToString ());
 			}
 		}
+		
+		void InitPixbuf ()
+		{
+			// For some reason, the first time we ask for the allocation,
+			// it's a 1x1 pixel.  Prevent against this by returning a
+			// reasonable default.  Setting the icon causes OnSizeAllocated
+			// to be called again anyhow.
+			if (panel_size < 16)
+				panel_size = 16;
+			
+			// Control specifically which icon is used at the smaller sizes
+			// so that no scaling occurs.  In the case of the panel applet,
+			// add a couple extra pixels of padding so it matches the behavior
+			// of the notification area tray icon.  See bug #403500 for more
+			// info.
+			int icon_size = panel_size;
+			if (Tomboy.IsPanelApplet)
+				icon_size = panel_size - 2;	// padding
+			if (icon_size <= 21)
+				icon_size = 16;
+			else if (icon_size <= 31)
+				icon_size = 22;
+			else if (icon_size <= 47)
+				icon_size = 32;
+
+			Gdk.Pixbuf new_icon = GuiUtils.GetIcon ("tomboy", icon_size);
+			image.Pixbuf = new_icon;
+		}
+		
+		///
+		/// Determine whether the tray is inside a horizontal or vertical
+		/// panel so the size of the icon can adjust correctly.
+		///
+		PanelOrientation GetPanelOrientation ()
+		{
+			if (this.ParentWindow == null) {
+				return PanelOrientation.Horizontal;
+			}
+			
+			Gdk.Window top_level_window = this.ParentWindow.Toplevel;
+			
+			Gdk.Rectangle rect = top_level_window.FrameExtents;
+			if (rect.Width < rect.Height)
+				return PanelOrientation.Vertical;
+			
+			return PanelOrientation.Horizontal;
+		}
 
 		protected override void OnSizeAllocated (Gdk.Rectangle rect)
 		{
-			// When running TrayIcon inside the notification area,
-			// gnome-panel is incorrectly reporting the width and
-			// height.  Depending on whether you're using a vertical
-			// or horizontal panel, one of rect.Width/rect.Height
-			// doesn't change when OnSizeAllocated is called after
-			// the panel size grows/shrinks.
-			int icon_size = -1;
-			if (Allocation.Width != rect.Width)
-				icon_size = rect.Width;
-			else if (Allocation.Height != rect.Height)
-				icon_size = rect.Height;
-			
 			base.OnSizeAllocated (rect);
-			
-			if (icon_size > 1) {
-				Gdk.Pixbuf new_icon = GuiUtils.GetIcon ("tomboy", icon_size);
-				if (image.Pixbuf.Width != new_icon.Width ||
-				    image.Pixbuf.Height != new_icon.Height) {
-					image.Pixbuf = new_icon;
-				}
+
+			// Determine the orientation
+			if (GetPanelOrientation () == PanelOrientation.Horizontal) {
+				if (panel_size == Allocation.Height)
+					return;
+				
+				panel_size = Allocation.Height;
+			} else {
+				if (panel_size == Allocation.Width)
+					return;
+				
+				panel_size = Allocation.Width;
 			}
+			
+			InitPixbuf ();
 		}
 	}
 
