@@ -68,14 +68,12 @@ namespace Tomboy
 		{
 			try {
 				return Gtk.IconTheme.Default.LoadIcon (resource_name, size, 0);
-			} catch (GLib.GException e) {
-			}
+			} catch (GLib.GException) {}
 
 			try {
 				Gdk.Pixbuf ret = new Gdk.Pixbuf (null, resource_name + ".png");
 				return ret.ScaleSimple (size, size, Gdk.InterpType.Bilinear);
-			} catch (ArgumentException e) {
-			}
+			} catch (ArgumentException) {}
 
 			Logger.Log ("Unable to load icon '{0}'.", resource_name);
 			return null;
@@ -116,7 +114,7 @@ namespace Tomboy
 					filename, 
 					link_id, 
 					screen);
-			} catch (GLib.GException e) {
+			} catch {
 				string message = 
 					Catalog.GetString ("The \"Tomboy Notes Manual\" could " +
 							   "not be found.  Please verify " +
@@ -216,6 +214,7 @@ namespace Tomboy
 			}
 
 			image.Show ();
+			image.Yalign = 0;
 			hbox.PackStart (image, false, false, 0);
 			
 			Gtk.VBox label_vbox = new Gtk.VBox (false, 0);
@@ -342,7 +341,8 @@ namespace Tomboy
 		public UriList (Gtk.SelectionData selection) 
 		{
 			// FIXME this should check the atom etc.
-			LoadFromString (Encoding.UTF8.GetString (selection.Data));
+			if (selection.Length > 0)
+				LoadFromString (Encoding.UTF8.GetString (selection.Data));
 		}
 
 		public override string ToString () 
@@ -777,22 +777,25 @@ namespace Tomboy
 	public class Application
 	{
 		static Gnome.Program program;
+		static ActionManager action_manager;
 
 		public static void Initialize (string locale_dir, 
 					       string display_name, 
 					       string process_name,  
 					       string [] args)
 		{
-			SetProcessName (process_name);
-
-			// Initialize GETTEXT
-			Catalog.Init (locale_dir, Defines.GNOME_LOCALE_DIR);
+			try {
+				SetProcessName (process_name);
+			} catch {} // Ignore exception if fail (not needed to run)
 
 			Gtk.Application.Init ();
 			program = new Gnome.Program ("Tomboy", 
 						     Defines.VERSION, 
 						     Gnome.Modules.UI, 
 						     args);
+			
+			action_manager = new ActionManager ();
+			action_manager.LoadInterface ();
 
 			RegisterSignalHandlers ();
 		}
@@ -895,5 +898,10 @@ namespace Tomboy
 		{
 			Gtk.Main.Quit ();
 		}
+		
+		public static ActionManager ActionManager
+		{
+			get { return action_manager; }
+		}
 	}
 }
